#!/usr/bin/python
##### Razmerje G/T sprejemne postaje - S53MV 10.03.2018 #####

import math	#uporabljene funkcije

kn=1.1		#korak risanja
nmin=0.15
nmax=100.0

tn=10		#temperatura neba
tz=290		#temperatura tal
tr=0		#temperatura sprejemnika

fd=0.4				#razmerje f/d zrcala
alfa=2*math.atan(0.25/fd)	#kot roba zrcala

x=[]		#polja za risanje grafa
y=[]
z=[]
w=[]
u=[]

def ftf(n,t):	#smerni diagram zarilca cos(t)^n
	return (math.cos(t))**n

def t3db(n):	#kot sevanja zarilca -3dB
	return math.acos(math.sqrt(2)**(-1/n))

def etas(n,alfa):	#izracun izkoristka sevanja preko roba 0<etas<1
	t=0
	kt=math.pi/200	#korak integracije
	es=0
	esr=0
	while t<=math.pi/2:
		f=ftf(n,t)		#smerni diagram zarilca
		ff=f*f*math.sin(t)	#lamejev koef. sin(theta)
		esr=esr+ff		#referencna vsota
		if t<alfa:
			es=es+ff	#koristna vsota
		t=t+kt
	return es/esr

def etao(n,fd):	#izracun izkoristka osvetlitve odprtine 0<etao<1
	kr=0.25/100	#korak integracije
	ro2=kr/2
	p=0
	m=0
	a=0
	while ro2<0.25:
		z=0.25*ro2/fd			#visina zrcalne ploskve
		l=math.sqrt(ro2+(fd-z)**2)	#oddaljenost ploskve od gorisca
		t=math.asin(math.sqrt(ro2)/l)	#kot theta iz gorisca
		f=ftf(n,t)			#smerni diagram zarilca
		e=f*fd/l			#polje osvetlitve odprtine
		p=p+e		#integral polja
		m=m+e*e		#integral moci
		a=a+1		#integral povrsine
		ro2=ro2+kr
	return p*p/m/a

def uorz(n,fd):	#izracun upada osvetlitve na robu zrcala v dB
	lf=1+(0.25/fd)**2
	f=ftf(n,2*math.atan(0.25/fd))
	return 20*math.log10(lf*f)

n=nmin
while n<=nmax:
	eo=etao(n,fd)		#izracun izkoristka osvetlitve odprtine
	es=etas(n,alfa)		#izracun izkoristka sevanja preko roba
	w=w+[es*eo*100]		#risanje skupnega izkoristka osvetlitve [%]
	ta=es*tn+(1-es)*tz	#izracun sumne temperature antene
	tt=ta+tr
	z=z+[tt]		#risanje skupne sumne temperature [K]
	y=y+[es*eo/tt*1000]	#risanje razmerja G/T*1000 [1/K]
	u=u+[-uorz(n,fd)]	#upad osvetlitve na robu zrcala [dB]
	x=x+[t3db(n)]		#vodoravna skala v theta-3dB zarilca [rd]
	n=n*kn			#pomnozi n za korak

import matplotlib.pyplot as plt		#risanje grafa funkcije
fig=plt.figure()
plt.plot(x,u,'y-')	#upad osvetlitve na robu zrcala [dB]
plt.plot(x,w,'g-')	#skupni izkoristek osvetlitve [%]
plt.plot(x,z,'r-')	#sumna temperatura antene [K]
plt.plot(x,y,'b-')	#razmerje G/T*1000 [1/K]
plt.axis([0,math.pi/2,0,100])
plt.xticks([0.0,math.pi/8,math.pi/4,3*math.pi/8,math.pi/2],['0',r'$\pi$/8',r'$\pi$/4',r'3$\pi$/8',r'$\pi$/2'])
plt.title('Razmerje G/T zrcalne antene')
plt.xlabel(r'Kot sevanja $\Theta$(-3dB) [rd]')
plt.grid(True)
fig.savefig('gt.svg', transparent=True)
plt.show()

#konec programa

