#!/usr/bin/python
##### Razmerje G/T sprejemne postaje - S53MV 10.03.2018 #####

import math	#uporabljene funkcije

kn=1.1		#korak risanja
nmin=0.15
nmax=100.0

tn=10		#temperatura neba
tz=290		#temperatura tal
tr=0		#temperatura sprejemnika

fd=0.6		#razmerje f/d zrcala
gts=1000	#skala razmerja G/T

u=[]		#polja za risanje grafa
v=[]
w=[]
x=[]
y=[]
z=[]

def ftf(n,t):	#smerni diagram zarilca cos(t)^n
	return (math.cos(t))**n

def etas(n,fd):	#izracun izkoristka sevanja preko roba 0<etas<1
	t=0
	kt=math.pi/200	#korak integracije
	alfa=2*math.atan(0.25/fd)
	es=0
	esr=0
	while t<=math.pi/2:
		f=ftf(n,t)		#smerni diagram zarilca
		ff=f*f*math.sin(t)	#lamejev koef. sin(theta)
		esr=esr+ff		#referencna vsota
		if t<alfa:
			es=es+ff	#koristna vsota
		t=t+kt
	return es/esr

def etao(n,fd):	#izracun izkoristka osvetlitve odprtine 0<etao<1
	kr=0.25/100	#korak integracije
	ro2=kr/2
	p=0
	m=0
	a=0
	while ro2<0.25:
		z=0.25*ro2/fd			#visina zrcalne ploskve
		l=math.sqrt(ro2+(fd-z)**2)	#oddaljenost ploskve od gorisca
		t=math.asin(math.sqrt(ro2)/l)	#kot theta iz gorisca
		f=ftf(n,t)			#smerni diagram zarilca
		e=f*fd/l			#polje osvetlitve odprtine
		p=p+e		#integral polja
		m=m+e*e		#integral moci
		a=a+1		#integral povrsine
		ro2=ro2+kr
	return p*p/m/a

def uorz(n,fd):	#izracun upada osvetlitve na robu zrcala v dB
	lf=1+(0.25/fd)**2
	f=ftf(n,2*math.atan(0.25/fd))
	return 20*math.log10(lf*f)

n=nmin
while n<=nmax:
	eo=etao(n,fd)		#izracun izkoristka osvetlitve odprtine
	v=v+[eo*100]		#risanje izkoristka osvetlitve odprtine [%]
	es=etas(n,fd)		#izracun izkoristka sevanja preko roba
	w=w+[es*100]		#risanje izkoristka sevanja preko roba [%]
	x=x+[es*eo*100]		#risanje skupnega izkoristka osvetlitve [%]
	ta=es*tn+(1-es)*tz	#izracun sumne temperature antene
	tt=ta+tr
	y=y+[tt]		#risanje skupne sumne temperature [K]
	z=z+[es*eo/tt*gts]	#risanje razmerja G/T*1000 [1/K]
	u=u+[uorz(n,fd)]	#upad osvetlitve na robu zrcala [dB]
	n=n*kn			#pomnozi n za korak

import matplotlib.pyplot as plt		#risanje grafa funkcije
fig=plt.figure()
plt.plot(u,v,'c--')	#izkoristek osvetlitve odprtine [%]
plt.plot(u,w,'y--')	#izkoristek sevanja preko roba [%]
plt.plot(u,x,'g-')	#skupni izkoristek osvetlitve [%]
plt.plot(u,y,'r-')	#sumna temperatura antene [K]
plt.plot(u,z,'b-')	#razmerje G/T*1000 [1/K]
plt.axis([-40,0,0,110])
plt.title(r'Razmerje $G$/$T_A$ zrcalne antene')
plt.xlabel(r'Upad osvetlitve na robu zrcala $a$ [dB]')
plt.grid(True)
fig.savefig('gta.svg', transparent=True)
plt.show()

#konec programa

